@@ -1,9 +1,13 @@
 package app
 
 import (
+	"bufio"
+	"bytes"
 	"context"
 	"fmt"
 	"os"
+	"path/filepath"
+	"strings"
 
 	"github.com/abiosoft/colima/cli"
 	"github.com/abiosoft/colima/config"
@@ -113,6 +117,10 @@ func (c colimaApp) Start(conf config.Config) error {
 	}
 
 	log.Println("done")
+
+	if err := generateSSHConfig(); err != nil {
+		log.Trace("error generating ssh_config: %w", err)
+	}
 	return nil
 }
 
@@ -153,6 +161,10 @@ func (c colimaApp) Stop(force bool) error {
 	}
 
 	log.Println("done")
+
+	if err := generateSSHConfig(); err != nil {
+		log.Trace("error generating ssh_config: %w", err)
+	}
 	return nil
 }
 
@@ -196,6 +208,10 @@ func (c colimaApp) Delete() error {
 	}
 
 	log.Println("done")
+
+	if err := generateSSHConfig(); err != nil {
+		log.Trace("error generating ssh_config: %w", err)
+	}
 	return nil
 }
 
@@ -205,8 +221,50 @@ func (c colimaApp) SSH(layer bool, args ...string) error {
 		return fmt.Errorf("%s not running", config.CurrentProfile().DisplayName)
 	}
 
+	workDir, err := os.Getwd()
+	if err != nil {
+		return fmt.Errorf("error retrieving current working directory: %w", err)
+	}
+	// peek the current directory to see if it is mounted to prevent `cd` errors
+	// with limactl ssh
+	if err := func() error {
+		conf, err := limautil.InstanceConfig()
+		if err != nil {
+			return err
+		}
+		pwd, err := util.CleanPath(workDir)
+		if err != nil {
+			return err
+		}
+		for _, m := range conf.MountsOrDefault() {
+			location := m.MountPoint
+			if location == "" {
+				location = m.Location
+			}
+			location, err := util.CleanPath(location)
+			if err != nil {
+				log.Trace(err)
+				continue
+			}
+			if strings.HasPrefix(pwd, location) {
+				return nil
+			}
+		}
+		return fmt.Errorf("not a mounted directory: %s", workDir)
+	}(); err != nil {
+		// the errors returned here is not critical and thereby silenced.
+		// the goal is to prevent unecessary warning message from Lima.
+		log.Trace(fmt.Errorf("error checking if PWD is mounted: %w", err))
+
+		// fallback to the user's homedir
+		username, err := c.guest.User()
+		if err == nil {
+			workDir = "/home/" + username + ".linux"
+		}
+	}
+
 	if !layer {
-		return c.guest.RunInteractive(args...)
+		return c.guest.SSH(workDir, args...)
 	}
 
 	conf, err := limautil.InstanceConfig()
@@ -214,7 +272,7 @@ func (c colimaApp) SSH(layer bool, args ...string) error {
 		return err
 	}
 	if !conf.Layer {
-		return c.guest.RunInteractive(args...)
+		return c.guest.SSH(workDir, args...)
 	}
 
 	resp, err := limautil.ShowSSH(config.CurrentProfile().ID, layer, "args")
@@ -227,15 +285,10 @@ func (c colimaApp) SSH(layer bool, args ...string) error {
 
 	cmdArgs := resp.Output
 
-	wd, err := os.Getwd()
-	if err != nil {
-		log.Debug(fmt.Errorf("cannot get working dir: %w", err))
-	}
-
 	if len(args) > 0 {
 		args = append([]string{"-q", "-t", resp.IPAddress, "--"}, args...)
-	} else if wd != "" {
-		args = []string{"-q", "-t", resp.IPAddress, "--", "cd " + wd + " 2> /dev/null; bash --login"}
+	} else if workDir != "" {
+		args = []string{"-q", "-t", resp.IPAddress, "--", "cd " + workDir + " 2> /dev/null; bash --login"}
 	}
 
 	args = append(util.ShellSplit(cmdArgs), args...)
@@ -376,3 +429,91 @@ func (c colimaApp) Kubernetes() (environment.Container, error) {
 func (c colimaApp) Active() bool {
 	return c.guest.Running(context.Background())
 }
+
+func generateSSHConfig() error {
+	instances, err := limautil.Instances()
+	if err != nil {
+		return fmt.Errorf("error retrieving instances: %w", err)
+	}
+	var buf bytes.Buffer
+
+	for _, i := range instances {
+		if !i.Running() {
+			continue
+		}
+
+		profile := config.Profile(i.Name)
+		conf, err := i.Config()
+		if err != nil {
+			log.Trace(fmt.Errorf("error retrieving profile config for '%s': %w", i.Name, err))
+			continue
+		}
+
+		resp, err := limautil.ShowSSH(profile.ID, conf.Layer, "config")
+		if err != nil {
+			log.Trace(fmt.Errorf("error retrieving SSH config for '%s': %w", i.Name, err))
+			continue
+		}
+
+		fmt.Fprintln(&buf, resp.Output)
+	}
+
+	sshFileColima := filepath.Join(filepath.Dir(config.Dir()), "ssh_config")
+	if err := os.WriteFile(sshFileColima, buf.Bytes(), 0644); err != nil {
+		return fmt.Errorf("error writing ssh_config file: %w", err)
+	}
+
+	includeLine := "Include " + sshFileColima
+
+	sshFileSystem := filepath.Join(util.HomeDir(), ".ssh", "config")
+
+	// include the SSH config file if not included
+	// if ssh file missing, the only content will be the include
+	if _, err := os.Stat(sshFileSystem); err != nil {
+		if err := os.MkdirAll(filepath.Dir(sshFileSystem), 0700); err != nil {
+			return fmt.Errorf("error creating ssh directory: %w", err)
+		}
+
+		if err := os.WriteFile(sshFileSystem, []byte(includeLine), 0644); err != nil {
+			return fmt.Errorf("error modifying %s: %w", sshFileSystem, err)
+		}
+
+		return nil
+	}
+
+	sshContent, err := os.ReadFile(sshFileSystem)
+	if err != nil {
+		return fmt.Errorf("error reading ssh config: %w", err)
+	}
+
+	scanner := bufio.NewScanner(bytes.NewReader(sshContent))
+	for scanner.Scan() {
+		words := strings.Fields(scanner.Text())
+
+		// empty line
+		if len(words) == 0 {
+			continue
+		}
+
+		// comment
+		if strings.HasPrefix(words[0], "#") {
+			continue
+		}
+
+		// not an include line
+		if len(words) < 2 {
+			continue
+		}
+
+		if words[0] == "Include" && words[1] == sshFileColima {
+			// already present
+			return nil
+		}
+	}
+
+	// not found, prepend file
+	if err := os.WriteFile(sshFileSystem, []byte(includeLine+"\n\n"+string(sshContent)), 0644); err != nil {
+		return fmt.Errorf("error modifying %s: %w", sshFileSystem, err)
+	}
+	return nil
+}
