@@ -14,7 +14,6 @@ import (
 	"github.com/abiosoft/colima/cmd/root"
 	"github.com/abiosoft/colima/config"
 	"github.com/abiosoft/colima/daemon/process/gvproxy"
-	"github.com/abiosoft/colima/util"
 	"github.com/sirupsen/logrus"
 )
 
@@ -33,10 +32,6 @@ func qemuWrapper(qemu string) {
 		config.SetProfile(profile)
 	}
 
-	// remove colima wrapper from path
-	binDir := filepath.Join(config.WrapperDir(), "bin")
-	_ = os.Setenv("PATH", util.RemoveFromPath(os.Getenv("PATH"), binDir))
-
 	info := gvproxy.Info()
 
 	// check if qemu is meant to run by lima
