@@ -1,9 +1,7 @@
 package config
 
 import (
-	"fmt"
 	"net"
-	"os"
 	"path/filepath"
 	"strings"
 
@@ -84,7 +82,8 @@ type Config struct {
 	MountType string  `yaml:"mountType,omitempty"`
 
 	// Runtime is one of docker, containerd.
-	Runtime string `yaml:"runtime,omitempty"`
+	Runtime         string `yaml:"runtime,omitempty"`
+	ActivateRuntime *bool  `yaml:"autoActivate,omitempty"`
 
 	// Kubernetes configuration
 	Kubernetes Kubernetes `yaml:"kubernetes,omitempty"`
@@ -94,6 +93,9 @@ type Config struct {
 
 	// layer
 	Layer bool `yaml:"layer,omitempty"`
+
+	// provision scripts
+	Provision []Provision `yaml:"provision,omitempty"`
 }
 
 // Kubernetes is kubernetes configuration
@@ -107,29 +109,19 @@ type Kubernetes struct {
 type Network struct {
 	Address bool     `yaml:"address"`
 	DNS     []net.IP `yaml:"dns"`
+	Driver  string   `yaml:"driver"`
 }
 
 // Mount is volume mount
 type Mount struct {
-	Location string `yaml:"location"`
-	Writable bool   `yaml:"writable"`
+	Location   string `yaml:"location"`
+	MountPoint string `yaml:"mountPoint,omitempty"`
+	Writable   bool   `yaml:"writable"`
 }
 
-// CleanPath returns the absolute path to the mount location.
-func (m Mount) CleanPath() (string, error) {
-	split := strings.SplitN(m.Location, ":", 2)
-	str := os.ExpandEnv(split[0])
-
-	if strings.HasPrefix(str, "~") {
-		str = strings.Replace(str, "~", util.HomeDir(), 1)
-	}
-
-	str = filepath.Clean(str)
-	if !filepath.IsAbs(str) {
-		return "", fmt.Errorf("relative paths not supported for mount '%s'", m.Location)
-	}
-
-	return strings.TrimSuffix(str, "/") + "/", nil
+type Provision struct {
+	Mode   string `yaml:"mode"`
+	Script string `yaml:"script"`
 }
 
 func (c Config) MountsOrDefault() []Mount {
@@ -143,6 +135,14 @@ func (c Config) MountsOrDefault() []Mount {
 	}
 }
 
+// AutoActivate returns if auto-activation of host client config is enabled.
+func (c Config) AutoActivate() bool {
+	if c.ActivateRuntime == nil {
+		return true
+	}
+	return *c.ActivateRuntime
+}
+
 // Empty checks if the configuration is empty.
 func (c Config) Empty() bool { return c.Runtime == "" } // this may be better but not really needed.
 
