@@ -7,6 +7,7 @@ import (
 	"strconv"
 
 	"github.com/abiosoft/colima/config"
+	"github.com/abiosoft/colima/util"
 )
 
 type buildArgs struct {
@@ -68,15 +69,6 @@ func (u ubuntuRuntime) buildArgs() (b buildArgs, err error) {
 	return
 }
 
-func (u ubuntuRuntime) imageBasename() string {
-	return "ubuntu-layer-" + string(u.guest.Arch().Value())
-}
-
-func (u ubuntuRuntime) imageArchive() string {
-	name := "ubuntu-layer-" + string(u.guest.Arch().Value()) + ".tar.gz"
-	return filepath.Join("/usr/share/colima", name)
-}
-
 func (u ubuntuRuntime) imageCreated() bool {
 	args := nerdctl("image", "inspect", imageName)
 	return u.guest.RunQuiet(args...) == nil
@@ -159,7 +151,16 @@ func (u ubuntuRuntime) createContainer(conf config.Config) error {
 
 	mounts := conf.MountsOrDefault()
 	for _, m := range mounts {
-		args = append(args, "--volume", m.Location+":"+m.Location)
+		location := m.MountPoint
+		if location == "" {
+			location = m.Location
+		}
+
+		location, err := util.CleanPath(location)
+		if err != nil {
+			return err
+		}
+		args = append(args, "--volume", location+":"+location)
 	}
 
 	env := conf.Env
@@ -170,3 +171,19 @@ func (u ubuntuRuntime) createContainer(conf config.Config) error {
 	args = append(args, imageName)
 	return u.guest.Run(args...)
 }
+
+func (u ubuntuRuntime) syncHostname() error {
+	currentHostname := func() string {
+		args := nerdctl("exec", containerName, "hostname")
+		hostname, _ := u.guest.RunOutput(args...)
+		return hostname
+	}()
+
+	hostname := config.CurrentProfile().ID
+	if currentHostname == hostname {
+		return nil
+	}
+
+	args := nerdctl("exec", containerName, "sudo", "hostname", hostname)
+	return u.guest.RunQuiet(args...)
+}
