@@ -4,8 +4,10 @@ import (
 	"bytes"
 	"errors"
 	"fmt"
+	"io"
 	"os"
 	"os/exec"
+	"strconv"
 	"strings"
 
 	"github.com/abiosoft/colima/util/terminal"
@@ -62,10 +64,17 @@ func (h hostEnv) RunQuiet(args ...string) error {
 	}
 	cmd := cli.Command(args[0], args[1:]...)
 	cmd.Env = append(os.Environ(), h.env...)
-	cmd.Stdout = nil
-	cmd.Stderr = nil
 
-	return cmd.Run()
+	var errBuf bytes.Buffer
+	cmd.Stdout = nil
+	cmd.Stderr = &errBuf
+
+	err := cmd.Run()
+	if err != nil {
+		return errCmd(cmd.Args, errBuf, err)
+	}
+
+	return nil
 }
 
 func (h hostEnv) RunOutput(args ...string) (string, error) {
@@ -76,16 +85,28 @@ func (h hostEnv) RunOutput(args ...string) (string, error) {
 	cmd := cli.Command(args[0], args[1:]...)
 	cmd.Env = append(os.Environ(), h.env...)
 
-	var buf bytes.Buffer
+	var buf, errBuf bytes.Buffer
 	cmd.Stdout = &buf
-	cmd.Stderr = nil
+	cmd.Stderr = &errBuf
 
-	if err := cmd.Run(); err != nil {
-		return "", err
+	err := cmd.Run()
+	if err != nil {
+		return "", errCmd(cmd.Args, errBuf, err)
 	}
+
 	return strings.TrimSpace(buf.String()), nil
 }
 
+func errCmd(args []string, stderr bytes.Buffer, err error) error {
+	// this is going to be part of a log output,
+	// reading the first line of the error should suffice
+	output, _ := stderr.ReadString('\n')
+	if len(output) > 0 {
+		output = output[:len(output)-1]
+	}
+	return fmt.Errorf("error running %v, output: %s, err: %s", args, strconv.Quote(output), strconv.Quote(err.Error()))
+}
+
 func (h hostEnv) RunInteractive(args ...string) error {
 	if len(args) == 0 {
 		return errors.New("args not specified")
@@ -95,6 +116,26 @@ func (h hostEnv) RunInteractive(args ...string) error {
 	return cmd.Run()
 }
 
+func (h hostEnv) RunWith(stdin io.Reader, stdout io.Writer, args ...string) error {
+	if len(args) == 0 {
+		return errors.New("args not specified")
+	}
+	cmd := cli.CommandInteractive(args[0], args[1:]...)
+	cmd.Env = append(os.Environ(), h.env...)
+
+	cmd.Stdin = stdin
+	cmd.Stdout = stdout
+
+	var buf bytes.Buffer
+	cmd.Stderr = &buf
+
+	if err := cmd.Run(); err != nil {
+		return errCmd(cmd.Args, buf, err)
+	}
+
+	return nil
+}
+
 func (h hostEnv) Env(s string) string {
 	return os.Getenv(s)
 }
