@@ -3,9 +3,7 @@ package lima
 import (
 	"context"
 	"fmt"
-	"net"
 	"path/filepath"
-	"strconv"
 
 	"github.com/abiosoft/colima/config"
 	"github.com/abiosoft/colima/util"
@@ -45,9 +43,3 @@ func (l limaVM) copyCerts() error {
 	}
 	return nil
 }
-
-func (l limaVM) addHost(host string, ip net.IP) error {
-	line := fmt.Sprintf("%s\t%s", ip.String(), host)
-	line = fmt.Sprintf("echo -e %s >> /etc/hosts", strconv.Quote(line))
-	return l.Run("sudo", "sh", "-c", line)
-}
