@@ -1,7 +1,7 @@
 package lima
 
 import (
-	"bytes"
+	"bufio"
 	"context"
 	"encoding/json"
 	"fmt"
@@ -9,8 +9,11 @@ import (
 	"net"
 	"os"
 	"path/filepath"
+	"strconv"
+	"strings"
 	"time"
 
+	"github.com/abiosoft/colima/config/configmanager"
 	"github.com/abiosoft/colima/daemon"
 	"github.com/abiosoft/colima/daemon/process/gvproxy"
 	"github.com/abiosoft/colima/daemon/process/vmnet"
@@ -35,17 +38,7 @@ func New(host environment.HostActions) environment.VM {
 	envBinary := osutil.EnvColimaBinary + "=" + osutil.Executable()
 	envs = append(envs, envLimaInstance, envSubprocess, envBinary)
 
-	// use qemu wrapper for Lima by specifying wrapper binaries via env var
-	envs = append(envs, qemu.LimaDir().BinsEnvVar()...)
-
-	home, err := limaHome()
-	if err != nil {
-		err = fmt.Errorf("error detecting Lima config directory: %w", err)
-		logrus.Warnln(err)
-		logrus.Warnln("falling back to default '$HOME/.lima'")
-		home = filepath.Join(util.HomeDir(), ".lima")
-	}
-
+	home := limautil.LimaHome()
 	// consider making this truly flexible to support other VMs
 	return &limaVM{
 		host:         host.WithEnv(envs...),
@@ -61,30 +54,8 @@ const (
 	limactl            = "limactl"
 )
 
-func limaHome() (string, error) {
-	var buf bytes.Buffer
-	cmd := cli.Command("limactl", "info")
-	cmd.Stdout = &buf
-
-	if err := cmd.Run(); err != nil {
-		return "", fmt.Errorf("error retrieving lima info: %w", err)
-	}
-
-	var resp struct {
-		LimaHome string `json:"limaHome"`
-	}
-	if err := json.NewDecoder(&buf).Decode(&resp); err != nil {
-		return "", fmt.Errorf("error decoding json for lima info: %w", err)
-	}
-	if resp.LimaHome == "" {
-		return "", fmt.Errorf("error retrieving lima info, ensure lima version is >0.7.4")
-	}
-
-	return resp.LimaHome, nil
-}
-
-func (l limaVM) limaConfDir() string {
-	return filepath.Join(l.home, config.CurrentProfile().ID)
+func (l limaVM) limaConfFile() string {
+	return filepath.Join(l.home, config.CurrentProfile().ID, "lima.yaml")
 }
 
 var _ environment.VM = (*limaVM)(nil)
@@ -115,8 +86,8 @@ func (l *limaVM) startDaemon(ctx context.Context, conf config.Config) (context.C
 		return ctx, nil
 	}
 
-	ctxKeyVmnet := daemon.CtxKey(vmnet.Name())
-	ctxKeyGVProxy := daemon.CtxKey(gvproxy.Name())
+	ctxKeyVmnet := daemon.CtxKey(vmnet.Name)
+	ctxKeyGVProxy := daemon.CtxKey(gvproxy.Name)
 
 	// use a nested chain for convenience
 	a := l.Init(ctx)
@@ -126,7 +97,9 @@ func (l *limaVM) startDaemon(ctx context.Context, conf config.Config) (context.C
 
 	a.Stage("preparing network")
 	a.Add(func() error {
-		ctx = context.WithValue(ctx, ctxKeyGVProxy, true)
+		if conf.Network.Driver == gvproxy.Name {
+			ctx = context.WithValue(ctx, ctxKeyGVProxy, true)
+		}
 		if conf.Network.Address {
 			ctx = context.WithValue(ctx, ctxKeyVmnet, true)
 		}
@@ -204,8 +177,15 @@ func (l *limaVM) startDaemon(ctx context.Context, conf config.Config) (context.C
 	}
 
 	// preserve gvproxy context
-	if gvproxyEnabled, _ := ctx.Value(daemon.CtxKey(gvproxy.Name())).(bool); gvproxyEnabled {
-		l.host = l.host.WithEnv(gvproxy.SubProcessEnvVar + "=1")
+	if gvproxyEnabled, _ := ctx.Value(daemon.CtxKey(gvproxy.Name)).(bool); gvproxyEnabled {
+		var envs []string
+
+		// env var for subproxy to detect gvproxy
+		envs = append(envs, gvproxy.SubProcessEnvVar+"=1")
+		// use qemu wrapper for Lima by specifying wrapper binaries via env var
+		envs = append(envs, qemu.LimaDir().BinsEnvVar()...)
+
+		l.host = l.host.WithEnv(envs...)
 	}
 
 	return ctx, nil
@@ -240,20 +220,7 @@ func (l *limaVM) Start(ctx context.Context, conf config.Config) error {
 		return os.Remove(configFile)
 	})
 
-	// host file
-	{
-		// add docker host alias
-		a.Add(func() error {
-			return l.addHost("host.docker.internal", net.ParseIP("192.168.5.2"))
-		})
-		// prevent chroot host error for layer
-		a.Add(func() error {
-			return l.addHost(config.CurrentProfile().ID, net.ParseIP("127.0.0.1"))
-		})
-	}
-
-	// registry certs
-	a.Add(l.copyCerts)
+	l.addPostStartActions(a, conf)
 
 	// adding it to command chain to execute only after successful startup.
 	a.Add(func() error {
@@ -278,14 +245,12 @@ func (l limaVM) resume(ctx context.Context, conf config.Config) error {
 		return err
 	})
 
-	configFile := filepath.Join(l.limaConfDir(), "lima.yaml")
-
 	a.Add(func() error {
 		limaConf, err := newConf(ctx, conf)
 		if err != nil {
 			return err
 		}
-		return yamlutil.WriteYAML(limaConf, configFile)
+		return yamlutil.WriteYAML(limaConf, l.limaConfFile())
 	})
 
 	a.Stage("starting")
@@ -293,8 +258,7 @@ func (l limaVM) resume(ctx context.Context, conf config.Config) error {
 		return l.host.Run(limactl, "start", config.CurrentProfile().ID)
 	})
 
-	// registry certs
-	a.Add(l.copyCerts)
+	l.addPostStartActions(a, conf)
 
 	return a.Exec()
 }
@@ -381,6 +345,18 @@ func (l limaVM) Run(args ...string) error {
 	return a.Exec()
 }
 
+func (l limaVM) SSH(workingDir string, args ...string) error {
+	args = append([]string{limactl, "shell", "--workdir", workingDir, config.CurrentProfile().ID}, args...)
+
+	a := l.Init(context.Background())
+
+	a.Add(func() error {
+		return l.host.RunInteractive(args...)
+	})
+
+	return a.Exec()
+}
+
 func (l limaVM) RunInteractive(args ...string) error {
 	args = append([]string{lima}, args...)
 
@@ -445,8 +421,8 @@ func (l limaVM) Env(s string) (string, error) {
 }
 
 func (l limaVM) Created() bool {
-	stat, err := os.Stat(l.limaConfDir())
-	return err == nil && stat.IsDir()
+	stat, err := os.Stat(l.limaConfFile())
+	return err == nil && !stat.IsDir()
 }
 
 const configFile = "/etc/colima/colima.json"
@@ -499,3 +475,54 @@ func (l limaVM) Arch() environment.Arch {
 	a, _ := l.RunOutput("uname", "-m")
 	return environment.Arch(a)
 }
+
+func (l limaVM) addHost(host string, ip net.IP) error {
+	if hostsFile, err := l.Read("/etc/hosts"); err == nil && includesHost(hostsFile, host, ip) {
+		return nil
+	} else if err != nil {
+		logrus.Warnln(fmt.Errorf("cannot read /etc/hosts in the VM: %w", err))
+	}
+
+	line := fmt.Sprintf("%s\t%s", ip.String(), host)
+	line = fmt.Sprintf("echo -e %s >> /etc/hosts", strconv.Quote(line))
+	return l.Run("sudo", "sh", "-c", line)
+}
+
+func includesHost(hostsFileContent, host string, ip net.IP) bool {
+	scanner := bufio.NewScanner(strings.NewReader(hostsFileContent))
+	for scanner.Scan() {
+		str := strings.Fields(scanner.Text())
+		if str[0] != ip.String() {
+			continue
+		}
+		if len(str) > 1 && str[1] == host {
+			return true
+		}
+	}
+	return false
+}
+
+func (l limaVM) addPostStartActions(a *cli.ActiveCommandChain, conf config.Config) {
+	// host file
+	{
+		// add docker host alias
+		a.Add(func() error {
+			return l.addHost("host.docker.internal", net.ParseIP("192.168.5.2"))
+		})
+		// prevent chroot host error for layer
+		a.Add(func() error {
+			return l.addHost(config.CurrentProfile().ID, net.ParseIP("127.0.0.1"))
+		})
+	}
+
+	// registry certs
+	a.Add(l.copyCerts)
+
+	// preserve state
+	a.Add(func() error {
+		if err := configmanager.SaveToFile(conf, limautil.ColimaStateFile(config.CurrentProfile().ID)); err != nil {
+			logrus.Warnln(fmt.Errorf("error persisting Colima state: %w", err))
+		}
+		return nil
+	})
+}
